@@ -35,15 +35,23 @@ werror = False
 import os
 import platform
 
+mpil='unknown'
+with open('/usr/share/mpi-default-dev/debian_defaults') as f:
+  for line in f.readlines():
+    bits = line.split('=')
+    if bits[0] == "ARCH_DEFAULT_MPI_IMPL":
+      mpil = bits[1].strip()
+mpi=mpil.upper()
+
 from subprocess import check_output
 arch = check_output(['dpkg-architecture','-qDEB_HOST_MULTIARCH']).strip().decode()
 libdir = '/usr/lib/' + arch
 incdir = '/usr/include/' + arch
 
-d_mpi_path = libdir + '/openmpi'
+d_mpi_path = libdir + '/' + mpil
 mpi_prefix = os.path.split(os.path.realpath(d_mpi_path))[0]
 mpi_prefix = d_mpi_path
-mpi_libs = ['mpi_cxx', 'mpi']
+mpi_libs = ['mpi']
 
 netcdf = 4
 netcdf_prefix = [ '/usr/include', libdir]
@@ -98,9 +106,4 @@ if platform.architecture()[0] == '32bit':
 if platform.machine() in ('ppc', 'ppc64', 'ppc64le', 's390x'):
     cxx_extra += ' -Wno-strict-overflow -Wno-error=strict-overflow '
 
-# Low memory
-if platform.machine() in ('armhf', 'mips', 'mips3l', 'mips64el'):
-    cxx_extra += ' -Os -g1'
-    ld_extra += ' -Wl,-no-keep-memory'
-
 mathjax_path='file:///usr/share/javascript/mathjax/MathJax.js'
