@@ -3,9 +3,9 @@
 
 from debian.sid_options import *
 
-mpi = 'OPENMPI'
-mpi_include = '/usr/lib/' + arch + '/openmpi/include'
-mpi_lib = '/usr/lib/' + arch + '/openmpi/lib'
+# mpi = 'OPENMPI'
+mpi_include = '/usr/lib/' + arch + '/' + mpi.lower() + '/include'
+mpi_lib = '/usr/lib/' + arch + '/' + mpi.lower() + '/lib'
 mpi_prefix = [mpi_include,mpi_lib]
 
 cxx_extra=' -Wno-stringop-truncation'
